%bcond_with docs

# the compilation does not generate debuginfo
%define _debugsource_template %{nil}

%global pypi_name libcst

%global common_description %{expand:
LibCST parses Python source code as a CST tree that keeps all formatting
details (comments, whitespaces, parentheses, etc). It's useful for building
automated refactoring (codemod) applications and linters.

LibCST creates a compromise between an Abstract Syntax Tree (AST) and a
traditional Concrete Syntax Tree (CST). By carefully reorganizing and naming
node types and fields, it creates a lossless CST that looks and feels like an
AST.}

Name:           python-%{pypi_name}
Version:        1.2.0
Release:        %mkrel 1
Summary:        A concrete syntax tree with AST-like properties for Python 3

License:        MIT and (MIT and Python) and ASL 2.0
URL:            https://github.com/Instagram/LibCST
Group:          Development/Python
Source0:        LibCST.tar.xz
# created with command cargo vendor in native directory and compressing vendor directory
Source1:        LibCST-vendor-%{version}.tar.xz
# to use the above source
Source2:        config.toml


BuildRequires:  python3-devel
BuildRequires:  git
BuildRequires:  python3dist(pytest)
%if %{with docs}
BuildRequires:  graphviz
BuildRequires:  sed
BuildRequires:  python3-docs
BuildRequires:  python3-metakernel-python
BuildRequires:  python3dist(sphinx)
BuildRequires:  python3dist(nbsphinx) >= 0.4.2
BuildRequires:  python3dist(sphinx-rtd-theme) >= 0.4.3
%endif

%description
%{common_description}

%package -n     python3-%{pypi_name}
Summary:        %{summary}

%description -n python3-%{pypi_name}
%{common_description}

%prep
%autosetup -n LibCST -a1
#mv vendor native
%__mkdir -p .cargo
cp %{S:2} .cargo

%if %{with docs}
# Use local intersphinx inventory
sed -r \
    -e 's|https://docs.python.org/3|%{_docdir}/python3-docs/html|' \
    -i docs/source/conf.py
%endif

%generate_buildrequires
%pyproject_buildrequires -t

%build
export LIBCST_NO_LOCAL_SCHEME=true
%pyproject_wheel

%if %{with docs}
# generate html docs
PYTHONPATH=${PWD} sphinx-build-3 docs/source html
# remove the sphinx-build leftovers
rm -rf html/.{doctrees,buildinfo}
%endif

%install
%pyproject_install
%pyproject_save_files libcst

%check
%tox 

%files -n python3-%{pypi_name} -f %{pyproject_files}
%license LICENSE
%doc README.rst

%if %{with docs}
%doc html
%endif


%changelog
* Wed Apr 03 2024 papoteur <papoteur> 1.2.0-1.mga10
+ Revision: 2054072
- new 1.2.0
- build is now arched
- vendoring rust modules
- use tox for tests
+ wally <wally>
- imported package python-libcst

